@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-11-27'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2015-11-28'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -117,14 +117,8 @@ Currently it only supports a subset of features compared to other
 * Only support local Riap URL (e.g. `/Foo/bar`, not
   `http://example.org/Foo/bar`);
 
-* No tab completion;
-
 * No subcommands support yet;
 
-* No support for streaming input or output;
-
-* No support for cmdline_src argument specification property;
-
 * No support for per_arg_yaml (not used as often as per_arg_json, no core module
   for parsing YAML).
 
@@ -658,6 +652,9 @@ _
             if $args{pass_cmdline_object};
         push @l, 'eval { $_pci_r->{res} = ', $func_name, '(%_pci_args) };', "\n";
         push @l, 'if ($@) { $_pci_r->{res} = [500, "Function died: $@"] }', "\n";
+        if ($meta->{result_naked}) {
+            push @l, '$_pci_r->{res} = [200, "OK (envelope added by Perinci::CmdLine::Inline)", $_pci_r->{res}];', "\n";
+        }
         push @l, "}\n\n";
 
         # generate code to format & display result
@@ -822,7 +819,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.30 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-11-27.
+This document describes version 0.31 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-11-28.
 
 =head1 SYNOPSIS
 
@@ -875,14 +872,8 @@ C<Perinci::CmdLine::*> implementations:
 =item * Only support local Riap URL (e.g. C</Foo/bar>, not
 C<http://example.org/Foo/bar>);
 
-=item * No tab completion;
-
 =item * No subcommands support yet;
 
-=item * No support for streaming input or output;
-
-=item * No support for cmdline_src argument specification property;
-
 =item * No support for per_arg_yaml (not used as often as per_arg_json, no core module
 for parsing YAML).
 
@@ -1063,6 +1054,14 @@ that contains extra information.
 
 Return value:  (any)
 
+=head1 FAQ
+
+=head2 What about tab completion?
+
+Use L<App::GenPericmdCompleterScript> to generate a separate completion script.
+If you use L<Dist::Zilla>, see also L<Dist::Zilla::Plugin::GenPericmdScript>
+which lets you generate script (and its completion script) during build.
+
 =head1 SEE ALSO
 
 L<Perinci::CmdLine>, L<Perinci::CmdLine::Any>, L<Perinci::CmdLine::Lite>,
